@@ -1,7 +1,7 @@
 package App::shcompgen;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.12'; # VERSION
+our $DATE = '2015-09-17'; # DATE
+our $VERSION = '0.13'; # VERSION
 
 use 5.010001;
 use strict;
@@ -477,20 +477,21 @@ searched from PATH.
 
 _
             element_completion => sub {
-                require Complete::Util;
+                require Complete::File;
+                require Complete::Program;
 
                 my %args = @_;
                 my $word = $args{word} // '';
                 if ($word =~ m!/!) {
                     # user might want to mention a program file (e.g. ./foo)
                     return {
-                        words => Complete::Util::complete_file(
+                        words => Complete::File::complete_file(
                             word=>$word, ci=>1, filter=>'d|rxf'),
                         path_sep => '/',
                     };
                 } else {
                     # or user might want to mention a program in PATH
-                    Complete::Util::complete_program(word=>$word, ci=>1);
+                    Complete::Program::complete_program(word=>$word, ci=>1);
                 }
             },
         },
@@ -620,7 +621,7 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.12 of App::shcompgen (from Perl distribution App-shcompgen), released on 2015-09-03.
+This document describes version 0.13 of App::shcompgen (from Perl distribution App-shcompgen), released on 2015-09-17.
 
 =head1 FUNCTIONS
 
